==> cscec5b-storecloud-impl-3.0.1-20220819.082352-66-sources.jar: com/ejianc/business/storecloud/bean/OutDetailEntity.java <==
package com.ejianc.business.storecloud.bean;

import java.math.*;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 内部人员领料出库子表
 *
 * @author generator
 *
 */
 @TableName("ejc_storecloud_out_detail")
public class OutDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="out_id")
    private Long outId; // 主表id
    @TableField(value="material_type")
    private String materialType; // 材料类型
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料类型名称
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_code")
    private String materialCategoryCode; // 物资分类编码
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 计量单位id
    @TableField(value="material_unit_name")
    private String materialUnitName; // 计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 库存数量
    @TableField(value="inventory_price")
    private BigDecimal inventoryPrice; // 库存均价
    @TableField(value="surplus_tax_mny")
    private BigDecimal surplusTaxMny; // 库存金额含税
    @TableField(value="surplus_mny")
    private BigDecimal surplusMny; // 库存金额(无税)
    @TableField(value="out_number")
    private BigDecimal outNumber; // 申请数量
    @TableField(value="delivery_number")
    private BigDecimal deliveryNumber; // 出库数量
    @TableField(value="surplus_price")
    private BigDecimal surplusPrice; // 库存单价(无税)
    @TableField(value="surplus_tax_price")
    private BigDecimal surplusTaxPrice; // 库存单价
    @TableField(value="file_ids")
    private String fileIds; //图片ids
    @TableField(value="memo")
    private String memo; //备注
    @TableField(value="apply_id")
    private Long applyId; // 领料主键id
    @TableField(value="apply_detail_id")
    private Long applyDetailId; // 领料子表主键id

    public Long getOutId() {
        return outId;
    }

    public void setOutId(Long outId) {
        this.outId = outId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }


    public BigDecimal getOutNumber() {
        return outNumber;
    }

    public void setOutNumber(BigDecimal outNumber) {
        this.outNumber = outNumber;
    }

    public BigDecimal getDeliveryNumber() {
        return deliveryNumber;
    }

    public void setDeliveryNumber(BigDecimal deliveryNumber) {
        this.deliveryNumber = deliveryNumber;
    }

    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public BigDecimal getSurplusPrice() {
        return surplusPrice;
    }

    public void setSurplusPrice(BigDecimal surplusPrice) {
        this.surplusPrice = surplusPrice;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public BigDecimal getInventoryPrice() {
        return inventoryPrice;
    }

    public void setInventoryPrice(BigDecimal inventoryPrice) {
        this.inventoryPrice = inventoryPrice;
    }

    public BigDecimal getSurplusTaxMny() {
        return surplusTaxMny;
    }

    public void setSurplusTaxMny(BigDecimal surplusTaxMny) {
        this.surplusTaxMny = surplusTaxMny;
    }

    public BigDecimal getSurplusMny() {
        return surplusMny;
    }

    public void setSurplusMny(BigDecimal surplusMny) {
        this.surplusMny = surplusMny;
    }

    public BigDecimal getSurplusTaxPrice() {
        return surplusTaxPrice;
    }

    public void setSurplusTaxPrice(BigDecimal surplusTaxPrice) {
        this.surplusTaxPrice = surplusTaxPrice;
    }

    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }
}

==> cscec5b-storecloud-impl-3.0.1-20220914.110744-176-sources.jar: com/ejianc/business/storecloud/bean/OutDetailEntity.java <==
package com.ejianc.business.storecloud.bean;

import java.math.*;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 内部人员领料出库子表
 *
 * @author generator
 *
 */
 @TableName("ejc_storecloud_out_detail")
public class OutDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="out_id")
    private Long outId; // 主表id
    @TableField(value="material_type")
    private String materialType; // 材料类型
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料类型名称
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_code")
    private String materialCategoryCode; // 物资分类编码
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 计量单位id
    @TableField(value="material_unit_name")
    private String materialUnitName; // 计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 库存数量
    @TableField(value="inventory_price")
    private BigDecimal inventoryPrice; // 库存均价
    @TableField(value="surplus_tax_mny")
    private BigDecimal surplusTaxMny; // 库存金额含税
    @TableField(value="surplus_mny")
    private BigDecimal surplusMny; // 库存金额(无税)
    @TableField(value="out_number")
    private BigDecimal outNumber; // 申请数量
    @TableField(value="delivery_number")
    private BigDecimal deliveryNumber; // 出库数量
    @TableField(value="surplus_price")
    private BigDecimal surplusPrice; // 库存单价(无税)
    @TableField(value="surplus_tax_price")
    private BigDecimal surplusTaxPrice; // 库存单价
    @TableField(value="file_ids")
    private String fileIds; //图片ids
    @TableField(value="memo")
    private String memo; //备注
    @TableField(value="apply_id")
    private Long applyId; // 领料主键id
    @TableField(value="apply_detail_id")
    private Long applyDetailId; // 领料子表主键id
    @TableField(value="check_tax_mny")
    private BigDecimal checkTaxMny; //出库金额
    @TableField(value="end_num")
    private BigDecimal endNum;//剩余可用数量

    public Long getOutId() {
        return outId;
    }

    public void setOutId(Long outId) {
        this.outId = outId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }


    public BigDecimal getOutNumber() {
        return outNumber;
    }

    public void setOutNumber(BigDecimal outNumber) {
        this.outNumber = outNumber;
    }

    public BigDecimal getDeliveryNumber() {
        return deliveryNumber;
    }

    public void setDeliveryNumber(BigDecimal deliveryNumber) {
        this.deliveryNumber = deliveryNumber;
    }

    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public BigDecimal getSurplusPrice() {
        return surplusPrice;
    }

    public void setSurplusPrice(BigDecimal surplusPrice) {
        this.surplusPrice = surplusPrice;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public BigDecimal getInventoryPrice() {
        return inventoryPrice;
    }

    public void setInventoryPrice(BigDecimal inventoryPrice) {
        this.inventoryPrice = inventoryPrice;
    }

    public BigDecimal getSurplusTaxMny() {
        return surplusTaxMny;
    }

    public void setSurplusTaxMny(BigDecimal surplusTaxMny) {
        this.surplusTaxMny = surplusTaxMny;
    }

    public BigDecimal getSurplusMny() {
        return surplusMny;
    }

    public void setSurplusMny(BigDecimal surplusMny) {
        this.surplusMny = surplusMny;
    }

    public BigDecimal getSurplusTaxPrice() {
        return surplusTaxPrice;
    }

    public void setSurplusTaxPrice(BigDecimal surplusTaxPrice) {
        this.surplusTaxPrice = surplusTaxPrice;
    }

    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }

    public Long getApplyDetailId() {
        return applyDetailId;
    }

    public void setApplyDetailId(Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }


    public BigDecimal getCheckTaxMny() {
        return checkTaxMny;
    }

    public void setCheckTaxMny(BigDecimal checkTaxMny) {
        this.checkTaxMny = checkTaxMny;
    }

    public BigDecimal getEndNum() {
        return endNum;
    }

    public void setEndNum(BigDecimal endNum) {
        this.endNum = endNum;
    }
}
